@@ -635,7 +635,14 @@ class CfnWorkGroup(
             typing.Union[bool, aws_cdk.core.IResolvable]
         ] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional["TagsProperty"] = None,
+        tags: typing.Optional[
+            typing.Union[
+                aws_cdk.core.IResolvable,
+                typing.List[
+                    typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]
+                ],
+            ]
+        ] = None,
         work_group_configuration: typing.Optional[
             typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]
         ] = None,
@@ -1080,45 +1087,6 @@ class CfnWorkGroup(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
-    @jsii.data_type(
-        jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.TagsProperty",
-        jsii_struct_bases=[],
-        name_mapping={"tags": "tags"},
-    )
-    class TagsProperty:
-        def __init__(
-            self, *, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None
-        ) -> None:
-            """
-            :param tags: ``CfnWorkGroup.TagsProperty.Tags``.
-
-            see
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-tags.html
-            """
-            self._values = {}
-            if tags is not None:
-                self._values["tags"] = tags
-
-        @builtins.property
-        def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
-            """``CfnWorkGroup.TagsProperty.Tags``.
-
-            see
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-tags.html#cfn-athena-workgroup-tags-tags
-            """
-            return self._values.get("tags")
-
-        def __eq__(self, rhs) -> bool:
-            return isinstance(rhs, self.__class__) and rhs._values == self._values
-
-        def __ne__(self, rhs) -> bool:
-            return not (rhs == self)
-
-        def __repr__(self) -> str:
-            return "TagsProperty(%s)" % ", ".join(
-                k + "=" + repr(v) for k, v in self._values.items()
-            )
-
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.WorkGroupConfigurationProperty",
         jsii_struct_bases=[],
@@ -1421,7 +1389,14 @@ class CfnWorkGroupProps:
             typing.Union[bool, aws_cdk.core.IResolvable]
         ] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional["CfnWorkGroup.TagsProperty"] = None,
+        tags: typing.Optional[
+            typing.Union[
+                aws_cdk.core.IResolvable,
+                typing.List[
+                    typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]
+                ],
+            ]
+        ] = None,
         work_group_configuration: typing.Optional[
             typing.Union[
                 aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"
@@ -1447,8 +1422,6 @@ class CfnWorkGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html
         """
-        if isinstance(tags, dict):
-            tags = CfnWorkGroup.TagsProperty(**tags)
         self._values = {
             "name": name,
         }
@@ -1506,7 +1479,14 @@ class CfnWorkGroupProps:
         return self._values.get("state")
 
     @builtins.property
-    def tags(self) -> typing.Optional["CfnWorkGroup.TagsProperty"]:
+    def tags(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            aws_cdk.core.IResolvable,
+            typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]],
+        ]
+    ]:
         """``AWS::Athena::WorkGroup.Tags``.
 
         see
